const { formatMilliseconds } = require('af-fns');
const echo = require('af-echo');
const { reset, colorMagenta: magenta } = echo;
export class Estimate {
    constructor(total) {
        this.total = total;
        this.startTime = +new Date();
        this.startCircleTime = +new Date();
        this.echo = echo;
    }
    startProgress(total, roll = 0, msgAdd = '', echoLevel = 2) {
        this.total = total;
        this.startCircleTime = +new Date();
        const msg = `${reset}Time taken to start processing: ${magenta}${formatMilliseconds(+new Date() - this.startTime)}${msgAdd ? `${reset} / ${msgAdd}` : ''}`;
        if (process.stdin.isTTY && roll) {
            process.stdout.write(`\x1b[${roll}A${msg}\x1b[K\n`);
        }
        else {
            echo.log(echoLevel, msg);
        }
    }
    setTotal(total) {
        this.total = total;
    }
    print(processed, options) {
        var _a, _b, _c;
        const defaultOptions = {
            showPercent: true,
            showCount: true,
            showTakenTime: true,
            roll: 0,
            prefix: '',
            msg: '',
        };
        options = Object.assign(defaultOptions, options || {});
        if (!this.total) {
            echo.echo(`"Estimate": can't calculate time, "total" parameter is not set`);
            return;
        }
        const txtOf = ((_a = options.of) === null || _a === void 0 ? void 0 : _a.text) || '';
        const txtProcessed = ((_b = options.of) === null || _b === void 0 ? void 0 : _b.processed) || processed;
        const txtTotal = ((_c = options.of) === null || _c === void 0 ? void 0 : _c.total) || this.total;
        let processedString = options.showPercent ? `${magenta}${Math.ceil((txtProcessed / txtTotal) * 100)}${reset}%` : '';
        const countString = options.showCount ? `${txtOf}${magenta}${txtProcessed} ${reset}out of ${magenta}${txtTotal}` : '';
        processedString += (processedString ? ' (' : '') + countString + (processedString ? `${reset})` : '');
        let leftString = `${reset}Left: ${magenta}`;
        if (processed) {
            const msLeft = (+new Date() - this.startCircleTime) * ((this.total / processed) - 1);
            leftString += formatMilliseconds(msLeft);
        }
        else {
            leftString = '';
        }
        const processedTime = options.showTakenTime ? `${reset} / 🕒 ${magenta}${this.getTaken()} ${reset}` : '';
        const roll = options.roll || 0;
        const msgAdd = options.msg || '';
        const msg = `${reset}${options.prefix || ''}Processed ${processedString}${reset}. ${leftString}${processedTime}${msgAdd ? `${reset} / ${msgAdd}` : ''} `;
        if (process.stdin.isTTY && roll) {
            process.stdout.write(`\x1b[${roll}A${msg}\x1b[K\n`);
        }
        else {
            echo.echo(msg);
        }
    }
    getTaken(isReset = false, isShowMilliseconds = false) {
        const taken = formatMilliseconds(+new Date() - this.startTime, isShowMilliseconds);
        if (isReset) {
            this.reset();
        }
        return taken;
    }
    getRest(processed, fromStart) {
        if (processed && this.total) {
            const msLeft = (+new Date() - (fromStart ? this.startTime : this.startCircleTime)) * ((this.total / processed) - 1);
            return formatMilliseconds(msLeft);
        }
        return '';
    }
    taken(roll, msgAdd, options) {
        const msg = `${reset}Time spent: ${magenta}${this.getTaken()}${msgAdd ? `${reset} / ${msgAdd}` : ''}`;
        if (process.stdin.isTTY && roll) {
            process.stdout.write(`\x1b[${roll}A${msg}\x1b[K\n`);
        }
        else {
            echo.echo(msg, options);
        }
    }
    reset() {
        this.startTime = +new Date();
        this.startCircleTime = +new Date();
    }
}
//# sourceMappingURL=index.js.map